landscapeViewPadding property
The landscape view padding; when null, follows landscapePadding, or the rotation rule applied to the effective portrait view padding.
Implementation
final EdgeInsets? landscapeViewPadding;
The landscape view padding; when null, follows landscapePadding, or the rotation rule applied to the effective portrait view padding.
final EdgeInsets? landscapeViewPadding;