portraitSize property
The logical screen size in portrait orientation.
Desktop presets use their natural window dimensions here (typically wider than tall).
Implementation
final ui.Size portraitSize;
The logical screen size in portrait orientation.
Desktop presets use their natural window dimensions here (typically wider than tall).
final ui.Size portraitSize;