rotateToLandscape static method
The documented rotation rule for deriving landscape safe areas from portrait ones:
landscape = EdgeInsets.only(
left: portrait.top, right: portrait.top, bottom: portrait.bottom)
The notch/status area is mirrored to both sides and the home indicator is kept at the bottom.
Implementation
static EdgeInsets rotateToLandscape(EdgeInsets portrait) => EdgeInsets.only(
left: portrait.top,
right: portrait.top,
bottom: portrait.bottom,
);